Module error

Module error 

Module containing the error definitions of the parser.

Structs

ParsingError
A parsing error which indicates its line of origin in the text as well as the type of error.

Enums

ParsingErrorType
The type of a parsing error.