ParsingErrorType

Enum ParsingErrorType 

pub enum ParsingErrorType<ExternalErrorType>
where ExternalErrorType: Display + Error,
{ BothBraketsInLine, IsolatedClosingBraket, MissingColon, UnknownKeyword(String), MissingChild(String), FailedParsingValue, External(ExternalErrorType), }
The type of a parsing error.

Variants



BothBraketsInLine

Only one kind of curly brakets is allowed per line, which has been violated when this variant occurs.



IsolatedClosingBraket

A closing braket has been found where it was not expected.



MissingColon

A colon is missing between type and name of an element.



UnknownKeyword(String)

Type unknown to its parent.



MissingChild(String)

Missing child keyword.



FailedParsingValue

Failed to parse a value.



External(ExternalErrorType)

A custom type for handling parsing errors.