pub fn parse_value<T, ExternalErrorType>(
source: &str,
line: usize,
) -> Result<T, ParsingError<ExternalErrorType>>Expand description
Wrapper function to safely parse a type implementing FromStr or produce
a ParsingError.
pub fn parse_value<T, ExternalErrorType>(
source: &str,
line: usize,
) -> Result<T, ParsingError<ExternalErrorType>>Wrapper function to safely parse a type implementing FromStr or produce
a ParsingError.